@@ -28,15 +28,14 @@
 # function body
 signif_column <- function(data, p, ...) {
   # add new significance column based on standard APA guidelines
-  data %>%
-    dplyr::mutate(
-      .data = .,
-      significance = dplyr::case_when(
-        {{ p }} >= 0.050 ~ "ns",
-        {{ p }} < 0.050 & {{ p }} >= 0.010 ~ "*",
-        {{ p }} < 0.010 & {{ p }} >= 0.001 ~ "**",
-        {{ p }} < 0.001 ~ "***"
-      )
-    ) %>% # convert to tibble dataframe
+  dplyr::mutate(
+    .data = data,
+    significance = dplyr::case_when(
+      {{ p }} >= 0.050 ~ "ns",
+      {{ p }} < 0.050 & {{ p }} >= 0.010 ~ "*",
+      {{ p }} < 0.010 & {{ p }} >= 0.001 ~ "**",
+      {{ p }} < 0.001 ~ "***"
+    )
+  ) %>% # convert to tibble dataframe
     tibble::as_tibble(.)
 }
